@@ -8,19 +8,19 @@
  */
 // Used to set Application in caseinline=APP
 function setApplSpan(spanZ) {
-    var module = getParameterByName("DbPAR");
+    let module = getParameterByName("DbPAR");
     if (module === null) {
-        module = "WRITER";
+        module = "SHARED";
     }
-    var y = spanZ.getElementsByTagName("SPAN");
-    var n = y.length;
-    var foundAppl = false;
+    let y = spanZ.getElementsByTagName("SPAN");
+    let n = y.length;
+    let foundAppl = false;
     for (i = 0; i < n; i++) {
         if (y[i].getAttribute("id") === null){
             continue;
         }
         else if( y[i].getAttribute("id").startsWith(module)){
-            y[i].removeAttribute("hidden");
+            y[i].hidden = false;
             foundAppl=true;
         }
     }
@@ -29,8 +29,9 @@ function setApplSpan(spanZ) {
             continue;
         }
         else if( y[i].getAttribute("id").startsWith("default")){
+            y[i].hidden = true;
             if(!foundAppl){
-                y[i].removeAttribute("hidden");
+                y[i].hidden = false;
             }
         }
     }
@@ -38,77 +39,54 @@ function setApplSpan(spanZ) {
 // Used to set system in case, caseinline=SYSTEM
 function setSystemSpan(spanZ) {
     // if no System in URL, get browser system
-    var system = getParameterByName("System");
+    let system = getParameterByName("System");
     if (system === null) {
         system = getSystem();
     }
-    var y = spanZ.getElementsByTagName("SPAN");
-    var n = y.length;
-    var foundSystem = false;
-    for (i = 0; i < n; i++) {
+    let y = spanZ.getElementsByTagName("SPAN");
+    let n = y.length;
+    let foundSystem = false;
+
+    for (let i = 0; i < n; i++) {
         if (y[i].getAttribute("id") === null){
             continue;
         }
         else if( y[i].getAttribute("id").startsWith(system)){
-            y[i].removeAttribute("hidden");
+            y[i].hidden = false;
             foundSystem=true;
         }
     }
-    for (i = 0; i < n; i++) {
+    for (let i = 0; i < n; i++) {
         if (y[i].getAttribute("id") === null){
             continue;
         }
         else if( y[i].getAttribute("id").startsWith("default")){
+            y[i].hidden = true;
             if(!foundSystem){
-                y[i].removeAttribute("hidden");
+                y[i].hidden = false;
             }
         }
     }
 }
 
 // paint headers and headings with appl color
-
 function moduleColor (module) {
     switch (module){
-        case "WRITER" : {color="#0369A3"; break;}
-        case "CALC"   : {color="#43C330"; break;}
+        case "WRITER" : {color="#083fa6"; break;}
+        case "CALC"   : {color="#007c3c"; break;}
         case "CHART"  : {color="darkcyan"; break;}
-        case "IMPRESS": {color="#A33E03"; break;}
-        case "DRAW"   : {color="#C99C00"; break;}
-        case "BASE"   : {color="#8E03A3"; break;}
+        case "IMPRESS": {color="#d0120d"; break;}
+        case "DRAW"   : {color="#cb6d30"; break;}
+        case "BASE"   : {color="#7324a9"; break;}
         case "BASIC"  : {color="black"; break;}
-        case "MATH"   : {color="darkslategray"; break;}
-        case "SHARED" : {color="gray"; break;}
+        case "MATH"   : {color="#c10018"; break;}
+        case "SHARED" : {color="darkslategray"; break;}
         default : {color="#18A303"; break;}
     }
-    document.getElementById("TopLeftHeader").style.background = color;
-    document.getElementById("SearchFrame").style.background = color;
-    document.getElementById("DonationFrame").style.background = color;
-    var cols = document.getElementsByClassName('tableheadcell');
-    for(i = 0; i < cols.length; i++) {cols[i].style.backgroundColor = color;};
-    for (j of [1,2,3,4,5,6]) {
-        var hh = document.getElementsByTagName("H" + j);
-        for(i = 0; i < hh.length; i++) {
-            hh[i].style.color = color;
-            hh[i].style.borderBottomColor = color;
-        }
-    }
+    let root = document.documentElement;
+    root.style.setProperty('--module-color', color);
 }
 
-// Find spans that need the switch treatment and give it to them
-var spans = document.querySelectorAll("[class^=switch]");
-var n = spans.length;
-for (z = 0; z < n; z++) {
-    var id = spans[z].getAttribute("id");
-    if (id === null) {
-        continue;
-    }
-    else if (id.startsWith("swlnsys")) {
-        setSystemSpan(spans[z]);
-    } else {
-        setApplSpan(spans[z]);
-    }
-}
 /* add &DbPAR= and &System= to the links in DisplayArea div */
 /* skip for object files */
 function fixURL(module, system) {
@@ -186,7 +164,8 @@ function existingLang(lang) {
 function setupModules(lang) {
     var modulesNav = document.getElementById('modules-nav');
     if (!modulesNav.classList.contains('loaded')) {
-        var html =
+        let html =
+            '<a href="' + lang + '/text/shared/05/new_help.html?DbPAR=SHARED"><div class="office-icon"></div>%PRODUCTNAME</a>' +
             '<a href="' + lang + '/text/swriter/main0000.html?DbPAR=WRITER"><div class="writer-icon"></div>Writer</a>' +
             '<a href="' + lang + '/text/scalc/main0000.html?DbPAR=CALC"><div class="calc-icon"></div>Calc</a>' +
             '<a href="' + lang + '/text/simpress/main0000.html?DbPAR=IMPRESS"><div class="impress-icon"></div>Impress</a>' +
@@ -200,10 +179,12 @@ function setupModules(lang) {
     }
 }
 
-function setupLanguages(page) {
-    var langNav = document.getElementById('langs-nav');
+function setupLanguages(url) {
+    let langNav = document.getElementById('langs-nav');
+    if (!langNav) return;
+    let page = url.substring(url.search('/text/'));
     if (!langNav.classList.contains('loaded')) {
-        var html = '';
+        let html = '';
         languagesSet.forEach(function(lang) {
             html += '<a href="' + lang + page + '">' + ((lang in languageNames)? languageNames[lang]: lang) + '</a>';
         });
@@ -212,33 +193,6 @@ function setupLanguages(page) {
     }
 }
 
-// Test, if we are online
-if (document.body.getElementsByTagName('meta')) {
-    var _paq = _paq || [];
-    /* tracker methods like "setCustomDimension" should be called before "trackPageView" */
-    _paq.push(['disableCookies']);
-    _paq.push(['trackPageView']);
-    _paq.push(['enableLinkTracking']);
-    (function() {
-    var u="//piwik.documentfoundation.org/";
-    _paq.push(['setTrackerUrl', u+'piwik.php']);
-    _paq.push(['setSiteId', '68']);
-    var d=document, g=d.createElement('script'), s=d.getElementsByTagName('script')[0];
-    g.type='text/javascript'; g.async=true; g.defer=true; g.src=u+'piwik.js'; s.parentNode.insertBefore(g,s);
-    })();
-    var system = getParameterByName("System");
-} else {
-    var system = getSystem();
-}
-
-var module = getParameterByName("DbPAR");
-fixURL(module,system);
-moduleColor(module);
-var helpID = getParameterByName("HID");
-// only used in xhp pages with <help-id-missing/> tags
-var missingElement = document.getElementById("bm_HID2");
-if(missingElement != null){missingElement.innerHTML = helpID;}
-
 function debugInfo(dbg) {
     if (dbg == null) return;
     document.getElementById("DEBUG").style.display = "block";
@@ -247,20 +201,49 @@ function debugInfo(dbg) {
     document.getElementById("bm_HID").innerHTML = "HID is: "+helpID;
 }
 
-debugInfo(getParameterByName("Debug"));
+// Find spans that need the switch treatment and give it to them
+function impl_Switches(){
 
-// Mobile devices need the modules and langs on page load
-if (Math.max(document.documentElement.clientWidth, window.innerWidth || 0) < 960) {
-    var e = new Event('click');
-    var modulesBtn = document.getElementById('modules');
-    var langsBtn = document.getElementById('langs');
-    var modules = document.getElementById('modules-nav');
-    var langs = document.getElementById('langs-nav');
-    modules.setAttribute('data-a11y-toggle-open', '');
-    modulesBtn.dispatchEvent(e);
-    if (langs) {
-        langs.setAttribute('data-a11y-toggle-open', '');
-        langsBtn.dispatchEvent(e);
+    let spans = document.querySelectorAll("[class^=switch]");
+    let n = spans.length;
+    for (let z = 0; z < n; z++) {
+        let id = spans[z].getAttribute("id");
+        if (id === null) {
+            continue;
+        }
+        else if (id.startsWith("swlnsys")) {
+            setSystemSpan(spans[z]);
+        } else {
+        setApplSpan(spans[z]);
+        }
     }
 }
+// Main
+let module = getParameterByName("DbPAR");
+let system = getParameterByName("System");
+let helpID = getParameterByName("HID");
+impl_Switches();
+fixURL(module,system);
+moduleColor(module);
+// only used in xhp pages with <help-id-missing/> tags
+let missingElement = document.getElementById("bm_HID2");
+if(missingElement != null){missingElement.innerHTML = helpID;}
+
+debugInfo(getParameterByName("Debug"));
+
+// Mobile devices need the modules and langs displayed on page load
+if (Math.max(document.documentElement.clientWidth, window.innerWidth || 0) < 960) {
+    let modules = document.getElementById('modules-nav');
+    let langs = document.getElementById('langs-nav');
+    modules.removeAttribute('hidden');
+    if (langs) {
+        langs.removeAttribute('hidden');
+    }
+}
+
+const href = window.location.href;
+const lang = existingLang(getParameterByName("Language", href) || navigator.language);
+setupModules(lang);
+setupLanguages(href);
+
 /* vim:set shiftwidth=4 softtabstop=4 expandtab cinoptions=b1,g0,N-s cinkeys+=0=break: */
